%ifarch %{arm}
%define enable_tests	0
%else
%define enable_tests	0
%endif

Name:		engauge-digitizer
Version:	12.2.2
Release:	%mkrel 3
Summary:	Convert graphs or map files into numbers
Group:		Sciences/Other
License:	GPLv2+
URL:		http://markummitchell.github.io/engauge-digitizer/
Source0:	https://github.com/markummitchell/engauge-digitizer/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	%{name}.appdata.xml
Source2:	%{name}.svg
Source3:	%{name}-with-name.svg
Patch0:		%{name}-10.1-fix_test_script.patch
Patch1:		%{name}-11.3-fix_translations_path.patch
### Main building
BuildRequires:	desktop-file-utils
BuildRequires:	qttools5
BuildRequires:	qttools5-assistant
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(poppler-qt5)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(log4cpp)

### Doxygen for documentation
BuildRequires:	doxygen
BuildRequires:	texlive-collection-basic

%if %{enable_tests}
### Xvfb is needed to run a virtual X server used by tests
BuildRequires:	x11-server-xvfb
BuildRequires:	pkgconfig(Qt5Test)
%endif

%description
The Engauge Digitizer tool accepts image files
(like PNG, JPEG and TIFF) containing graphs,
and recovers the data points from those graphs.
The resulting data points are usually used as input
to other software applications.
Conceptually, Engauge Digitizer is the opposite of
a graphing tool that converts data points to graphs.
The process is shown below - an image file is imported,
digitized within Engauge, and exported as a table of
numeric data to a text file.
Work can be saved into an Engauge DIG file.

More details at "http://markummitchell.github.io/engauge-digitizer/"

%package	samples
Summary:	Sample files for %{name}
Group:		Documentation
BuildArch:	noarch

%description	samples
This package contains several sample image files that may be imported into
Engauge Digitizer.

More details in "/usr/share/doc/engauge-digitizer-samples/README"

%package	doc
Summary:	HTML documentation of %{name}
Group:		Documentation
BuildArch:	noarch

%description	doc
HTML documentation of %{name}.

%prep
%setup -q

%if %{enable_tests}
### optimization flags for compilers
%patch0 -p1
sed -e 's|RPM_OPT_FLAGS|"%{optflags}"|g' -i src/build_and_run_all_cli_tests
%endif

%patch1 -p1

### Remove default -O1 optimization
sed -e 's|-O1||g' -i engauge.pro

### Active support to jpeg2000 and support to pdf
sed -e 's|CONFIG += qt warn_on thread|CONFIG += qt warn_on thread jpeg2000 pdf|g' -i engauge.pro

### Remove spurious executable permissions
for i in `find src -type f \( -name "*.cpp" -o -name "*.h" \)`; do
chmod a-x $i
done

%build
export OPENJPEG_INCLUDE=%{_includedir}/openjpeg-2.4
export OPENJPEG_LIB=%{_libdir}
export POPPLER_INCLUDE=%{_includedir}/poppler/qt5
export POPPLER_LIB=%{_libdir}
export ENGAUGE_RELEASE=1

### Build engauge
%{_qt5_bindir}/lrelease engauge.pro
%qmake_qt5 engauge.pro DEFINES+=HELPDIR=%{_docdir}/%{name}/help
%make_build

### Build HELP files
pushd help
mkdir ../bin/documentation
%{_qt5_bindir}/qhelpgenerator engauge.qhcp -o engauge.qhc
mv engauge.qch ../bin/documentation
mv engauge.qhc ../bin/documentation
rm -f build
popd

### Build HTML/Latex documentation files
pushd src
doxygen
popd

%install
### Install binary
mkdir -p %{buildroot}%{_bindir}
install -p -m 755 bin/engauge %{buildroot}%{_bindir}

### Install sample files
mkdir -p %{buildroot}%{_datadir}/%{name}/samples
pushd samples
install -p -m 644 *.gif *.jp* *.p* *.bmp *.x* %{buildroot}%{_datadir}/%{name}/samples
popd

### Install img files
mkdir -p %{buildroot}%{_datadir}/%{name}/img
install -p -m 644 src/img/* %{buildroot}%{_datadir}/%{name}/img

### Install appdata file
mkdir -p %{buildroot}%{_datadir}/appdata
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/appdata

### Install icons svg
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -p -m 644 %{SOURCE2} %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -p -m 644 %{SOURCE3} %{buildroot}%{_iconsdir}/hicolor/scalable/apps

### Install translation files
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
install -p -m 0644 translations/*.qm %{buildroot}%{_datadir}/%{name}/translations/

### Install .desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=Engauge Digitizer
Type=Application
Comment=Extracts data points from images of graphs
Comment[fr]=Extraits des points de données à partir d'images de graphiques
TryExec=engauge
Exec=engauge %%F
MimeType=text/plain;
Categories=Education;Science;DataVisualization;
Icon=%{name}-with-name
Keywords=analog;digital;converter;
EOF

%check
### Tests
%if %{enable_tests}
pushd src
xvfb-run -s "-screen 0 640x480x24" -a  sh -x ./build_and_run_all_cli_tests
%endif

%files
%doc README.md help/
%doc bin/documentation/engauge.qhc bin/documentation/engauge.qch
%license LICENSE
%{_bindir}/engauge
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/scalable/apps/%{name}*.svg
%exclude %{_datadir}/%{name}/samples

%files samples
%doc samples/README
%license LICENSE
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/samples

%files doc
%doc README.md doc/doxygen/html
%license LICENSE


%changelog
* Wed Dec 30 2020 daviddavid <daviddavid> 12.2.2-3.mga8
+ Revision: 1665552
- rebuild for new openjpeg 2.4.0

* Wed Dec 16 2020 umeabot <umeabot> 12.2.2-2.mga8
+ Revision: 1658341
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 12.2.2-1.mga8
+ Revision: 1605901
- new version: 12.2.2

* Tue Feb 18 2020 umeabot <umeabot> 12.1-2.mga8
+ Revision: 1539202
- Mageia 8 Mass Rebuild

* Sat Nov 30 2019 daviddavid <daviddavid> 12.1-1.mga8
+ Revision: 1463866
- new version: 12.1

* Fri Aug 23 2019 daviddavid <daviddavid> 12-1.mga8
+ Revision: 1431402
- new version: 12

* Sun Jul 21 2019 daviddavid <daviddavid> 11.3-1.mga8
+ Revision: 1423250
- new version: 11.3

* Wed May 08 2019 daviddavid <daviddavid> 11.2-1.mga7
+ Revision: 1396654
- new version: 11.2
- improve descriptions

* Sat Mar 30 2019 umeabot <umeabot> 10.12-2.mga7
+ Revision: 1381635
- Qt5 Rebuild

* Thu Mar 07 2019 daviddavid <daviddavid> 10.12-1.mga7
+ Revision: 1372131
- new version: 10.12

* Wed Jan 23 2019 daviddavid <daviddavid> 10.11-2.mga7
+ Revision: 1360037
- qcollectiongenerator was merged in qhelpgenerator since Qt 5.12

* Mon Oct 29 2018 daviddavid <daviddavid> 10.11-1.mga7
+ Revision: 1326470
- new version: 10.11

* Thu Oct 11 2018 daviddavid <daviddavid> 10.10-1.mga7
+ Revision: 1319630
- new version: 10.10

* Sun Sep 23 2018 umeabot <umeabot> 10.9-2.mga7
+ Revision: 1297605
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 10.9-1.mga7
+ Revision: 1246990
- new version: 10.9

* Sat Jul 07 2018 daviddavid <daviddavid> 10.8-1.mga7
+ Revision: 1242424
- new version: 10.8

* Sat Jun 23 2018 daviddavid <daviddavid> 10.7.13-1.mga7
+ Revision: 1239116
- new version: 10.7.13

* Thu Jun 21 2018 daviddavid <daviddavid> 10.7.6-1.mga7
+ Revision: 1238562
- new version: 10.7.6

* Mon Jun 18 2018 daviddavid <daviddavid> 10.7.3-1.mga7
+ Revision: 1237898
- new version: 10.7.3

* Thu Jun 07 2018 daviddavid <daviddavid> 10.7-1.mga7
+ Revision: 1235072
- new version: 10.7

* Sun Apr 29 2018 daviddavid <daviddavid> 10.6-2.mga7
+ Revision: 1223602
- fix build with openjpeg2 2.3.0

* Mon Apr 09 2018 daviddavid <daviddavid> 10.6-1.mga7
+ Revision: 1216401
- new version: 10.6

* Wed Apr 04 2018 daviddavid <daviddavid> 10.5-1.mga7
+ Revision: 1215129
- new version: 10.5

* Fri Oct 20 2017 daviddavid <daviddavid> 10.4-1.mga7
+ Revision: 1172864
- new version: 10.4

* Thu Sep 21 2017 daviddavid <daviddavid> 10.3-2.mga7
+ Revision: 1156782
- rebuild for new poppler 0.59.0

* Tue Sep 05 2017 daviddavid <daviddavid> 10.3-1.mga7
+ Revision: 1151506
- new version: 10.3

* Fri Aug 25 2017 daviddavid <daviddavid> 10.2-1.mga7
+ Revision: 1147738
- new version: 10.2

* Sun Jul 23 2017 daviddavid <daviddavid> 10.1-1.mga7
+ Revision: 1128969
- new version: 10.1
- rediff and rename patches
- improve description

* Fri Dec 23 2016 daviddavid <daviddavid> 9.8-1.mga6
+ Revision: 1076664
- new version: 9.8

* Fri Dec 02 2016 daviddavid <daviddavid> 9.7-1.mga6
+ Revision: 1071629
- new version: 9.7

* Tue Nov 22 2016 daviddavid <daviddavid> 9.6-1.mga6
+ Revision: 1068773
- new version: 9.6

* Fri Oct 14 2016 daviddavid <daviddavid> 9.5-1.mga6
+ Revision: 1060744
- new version: 9.5

* Sun Oct 02 2016 daviddavid <daviddavid> 9.4-3.mga6
+ Revision: 1058108
- new version: 9.4
- package all translation files
- add BR texlive-collection-basic for build doc

* Wed Sep 07 2016 daviddavid <daviddavid> 9.3-1.mga6
+ Revision: 1050394
- new version: 9.3

* Sat Aug 13 2016 luigiwalser <luigiwalser> 9.1-2.mga6
+ Revision: 1046232
- test rebuild for poppler

* Thu Aug 11 2016 daviddavid <daviddavid> 9.1-1.mga6
+ Revision: 1045554
- new version: 9.1
- fix jpeg2000 support
- enable support to pdf with poppler-qt5
- rename and rediff fix_test_script patch
- improve desktop file and appdata file

* Sat Apr 09 2016 daviddavid <daviddavid> 7.2-1.mga6
+ Revision: 999816
- new version: 7.2

* Thu Mar 24 2016 daviddavid <daviddavid> 7.1-1.mga6
+ Revision: 995174
- new version: 7.1
+ blino <blino>
- re-enable tests on ARM, it should not fail and the failure did not look ARM-specific

* Mon Mar 07 2016 daviddavid <daviddavid> 7.0-2.mga6
+ Revision: 986929
- disable tests on arm

* Mon Mar 07 2016 daviddavid <daviddavid> 7.0-1.mga6
+ Revision: 986919
- new version: 7.0
- rename and rediff fix_test_script patch
- update of appdata file
- update of description
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 02 2015 daviddavid <daviddavid> 6.2-1.mga6
+ Revision: 907765
- imported package engauge-digitizer (based on Fedora)

